ajdmom.mdl\_1fsvj.cov
=====================

.. automodule:: ajdmom.mdl_1fsvj.cov

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cov
      cov_yy
      dcov
      moment_yy
   
   

   
   
   

   
   
   



